﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Windows.Documents;

namespace XamDataGridFieldChooser
{
    public class Company : INotifyPropertyChanged
    {

        public Company()
        {
            Employees = new List<Employee>();
            
        }

        public List<Employee> Employees
        {
            get;
            set;
        }

        public void AddEmployee(Employee employee)
        {
            Employees.Add(employee);
            employee.PropertyChanged += OnEmployeeChanged;
            RaisePropertyChanged("Employees");
        }

       

        private void OnEmployeeChanged(object sender, System.ComponentModel.PropertyChangedEventArgs e)
        {
            if (e.PropertyName.Equals("Hired"))
            {
                RaisePropertyChanged("EveryoneHired");
            }
        }


        public bool? EveryoneHired
        {
            //Returns true if all the employees are hired, false if none of them are hired, or null (indeterminate) otherwise.
            get
            {
                Employee first = Employees.FirstOrDefault();
                if (first != null)
                {
                    if (Employees.All(employee => employee.Hired == first.Hired))
                    {
                        return first.Hired;
                    }
                }
                return null;
            }

            set
            {
                //The "select all" checkbox is three-state, so handle the "null" case.
                bool newValue = value ?? false;

                //If all items are already selected or deselected, toggle their state.
                bool? everyoneHired = EveryoneHired;
                if (everyoneHired == newValue)
                {
                    newValue = !newValue;
                }
                Employees.ForEach(employee => employee.Hired = newValue);
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void RaisePropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}

  

